==> hmx_v2_python_test-1.2.0-py3-none-any.whl: hmx2/constants/contracts.py <==

CONTRACT_ADDRESS = {
  # Arbitrum One
  42161: {
    "MULTICALL_ADDRESS": "0xcA11bde05977b3631167028862bE2a173976CA11",
    "CROSS_MARGIN_HANDLER_ADDRESS": "0xB189532c581afB4Fbe69aF6dC3CD36769525d446",
    "LIMIT_TRADE_HANDLER_ADDRESS": "0xeE116128b9AAAdBcd1f7C18608C5114f594cf5D6",
    "GLP_MANAGER_ADDRESS": "0x3963FfC9dff443c2A94f21b129D429891E32ec18",
    "CONFIG_STORAGE_ADDRESS": "0xF4F7123fFe42c4C90A4bCDD2317D397E0B7d7cc0",
    "PERP_STORAGE_ADDRESS": "0x97e94BdA44a2Df784Ab6535aaE2D62EFC6D2e303",
    "VAULT_STORAGE_ADDRESS": "0x56CC5A9c0788e674f17F7555dC8D3e2F1C0313C0",
    "DIX_PRICE_ADAPTER_ADDRESS": "0x222918d230c5A29F334fFb3020aD57b8CeBD1B82",
    "GM_BTC_PRICE_ADAPTER_ADDRESS": "0x85680bba8a94c9be1DDd7Be802885DFCe95F8164",
    "GM_ETH_PRICE_ADAPTER_ADDRESS": "0x700083c72eBc86CbFc865830F5706a2DbC392f26",
    "TRADE_HELPER_ADDRESS": "0x963Cbe4cFcDC58795869be74b80A328b022DE00C",
    "ONCHAIN_PRICELENS_ADDRESS": "0x7D8eAa8dF02526c711F4ff1f97F6c5324212DBBa",
    "CALCULATOR_ADDRESS": "0x0FdE910552977041Dc8c7ef652b5a07B40B9e006",
    "INTENT_ADDRESS": "0xA5b749203967e3ddF48006a7d7C258E59Ac07A96",
    "ORDERBOOK_ORACLE_ADDRESS": "0x0f1e64330618eA1BEfE139B7f26A1e04629a8556",
    "ADAPTIVE_FEE_CALCULATOR_ADDRESS": "0xbd6ec85003730A05fb9c864880f86f40F199B185",
    "CALC_PRICELENS_ADDRESS": "0x8CE09F789235bdca8EC2EeE990B11c42E35909Fc"
  },
  # Blast Mainnet
  81457: {
    "MULTICALL_ADDRESS": "0xcA11bde05977b3631167028862bE2a173976CA11zz",
    "CROSS_MARGIN_HANDLER_ADDRESS": "0xE7D96684A56e60ffBAAe0fC0683879da48daB383",
    "LIMIT_TRADE_HANDLER_ADDRESS": "0xcf533D0eEFB072D1BB68e201EAFc5368764daA0E",
    "CONFIG_STORAGE_ADDRESS": "0x9F09b53ee28a93951fe546dEfB24C0f908eEda22",
    "PERP_STORAGE_ADDRESS": "0x9c83e1046dA4727F05C6764c017C6E1757596592",
    "VAULT_STORAGE_ADDRESS": "0x97e94BdA44a2Df784Ab6535aaE2D62EFC6D2e303",
    "DIX_PRICE_ADAPTER_ADDRESS": "0x7557573E674B55Da6c25fEa9f648b019D1Dfd499",
    "TRADE_HELPER_ADDRESS": "0x9F1f13eBC178122C3ef6c14FA3A523680563F58b",
    "ONCHAIN_PRICELENS_ADDRESS": "0x9C67046f42eFfbA03d58aA54cB9C75aFDa38146e",
    "CALCULATOR_ADDRESS": "0x4307fbDCD9Ec7AEA5a1c2958deCaa6f316952bAb",
    "CALC_PRICELENS_ADDRESS": "0xcDc77D7799E3BC1B5A1D55d6D973BfD337cF5A16",
    "GLP_MANAGER_ADDRESS": "",
    "GM_BTC_PRICE_ADAPTER_ADDRESS": "",
    "GM_ETH_PRICE_ADAPTER_ADDRESS": "",
    "INTENT_ADDRESS": "",
    "ORDERBOOK_ORACLE_ADDRESS": "",
    "ADAPTIVE_FEE_CALCULATOR_ADDRESS": "",
  },
}

# ------ ABI Path ------
ERC20_ABI_PATH = "abis/ERC20.json"
CROSS_MARGIN_HANDLER_ABI_PATH = "abis/CrossMarginHandler.json"
LIMIT_TRADE_HANDLER_ABI_PATH = "abis/LimitTradeHandler.json"
VAULT_STORAGE_ABI_PATH = "abis/VaultStorage.json"
GLP_MANAGER_ABI_PATH = "abis/GlpManager.json"
PERP_STORAGE_ABI_PATH = "abis/PerpStorage.json"
CONFIG_STORAGE_ABI_PATH = "abis/ConfigStorage.json"
CIX_PRICE_ADAPTER_ABI_PATH = "abis/CIXPriceAdapter.json"
GM_PRICE_ADAPTER_ABI_PATH = "abis/GMPriceAdapter.json"
TRADE_HELPER_ABI_PATH = "abis/TradeHelper.json"
ONCHAIN_PRICELENS_ABI_PATH = "abis/OnchainPricelens.json"
CALC_PRICELENS_ABI_PATH = "abis/CalcPricelens.json"
CALCULATOR_ABI_PATH = "abis/Calculator.json"
ORDERBOOK_ORACLE_ABI = "abis/OrderbookOracle.json"
ADAPTIVE_FEE_CALCULATOR_ABI = "abis/AdaptiveFeeCalculator.json"

==> hmx_v2_python_test-1.2.3-py3-none-any.whl: hmx2/constants/contracts.py <==

CONTRACT_ADDRESS = {
  # Arbitrum One
  42161: {
    "MULTICALL_ADDRESS": "0xcA11bde05977b3631167028862bE2a173976CA11",
    "CROSS_MARGIN_HANDLER_ADDRESS": "0xB189532c581afB4Fbe69aF6dC3CD36769525d446",
    "LIMIT_TRADE_HANDLER_ADDRESS": "0xeE116128b9AAAdBcd1f7C18608C5114f594cf5D6",
    "GLP_MANAGER_ADDRESS": "0x3963FfC9dff443c2A94f21b129D429891E32ec18",
    "CONFIG_STORAGE_ADDRESS": "0xF4F7123fFe42c4C90A4bCDD2317D397E0B7d7cc0",
    "PERP_STORAGE_ADDRESS": "0x97e94BdA44a2Df784Ab6535aaE2D62EFC6D2e303",
    "VAULT_STORAGE_ADDRESS": "0x56CC5A9c0788e674f17F7555dC8D3e2F1C0313C0",
    "DIX_PRICE_ADAPTER_ADDRESS": "0x222918d230c5A29F334fFb3020aD57b8CeBD1B82",
    "GM_BTC_PRICE_ADAPTER_ADDRESS": "0x85680bba8a94c9be1DDd7Be802885DFCe95F8164",
    "GM_ETH_PRICE_ADAPTER_ADDRESS": "0x700083c72eBc86CbFc865830F5706a2DbC392f26",
    "TRADE_HELPER_ADDRESS": "0x963Cbe4cFcDC58795869be74b80A328b022DE00C",
    "ONCHAIN_PRICELENS_ADDRESS": "0x7D8eAa8dF02526c711F4ff1f97F6c5324212DBBa",
    "CALCULATOR_ADDRESS": "0x0FdE910552977041Dc8c7ef652b5a07B40B9e006",
    "INTENT_ADDRESS": "0xA5b749203967e3ddF48006a7d7C258E59Ac07A96",
    "ORDERBOOK_ORACLE_ADDRESS": "0x0f1e64330618eA1BEfE139B7f26A1e04629a8556",
    "ADAPTIVE_FEE_CALCULATOR_ADDRESS": "0xbd6ec85003730A05fb9c864880f86f40F199B185",
    "CALC_PRICELENS_ADDRESS": "0x8CE09F789235bdca8EC2EeE990B11c42E35909Fc"
  },
  # Blast Mainnet
  81457: {
    "MULTICALL_ADDRESS": "0xcA11bde05977b3631167028862bE2a173976CA11",
    "CROSS_MARGIN_HANDLER_ADDRESS": "0xE7D96684A56e60ffBAAe0fC0683879da48daB383",
    "LIMIT_TRADE_HANDLER_ADDRESS": "0xcf533D0eEFB072D1BB68e201EAFc5368764daA0E",
    "CONFIG_STORAGE_ADDRESS": "0x9F09b53ee28a93951fe546dEfB24C0f908eEda22",
    "PERP_STORAGE_ADDRESS": "0x9c83e1046dA4727F05C6764c017C6E1757596592",
    "VAULT_STORAGE_ADDRESS": "0x97e94BdA44a2Df784Ab6535aaE2D62EFC6D2e303",
    "DIX_PRICE_ADAPTER_ADDRESS": "0x7557573E674B55Da6c25fEa9f648b019D1Dfd499",
    "TRADE_HELPER_ADDRESS": "0x9F1f13eBC178122C3ef6c14FA3A523680563F58b",
    "ONCHAIN_PRICELENS_ADDRESS": "0x9C67046f42eFfbA03d58aA54cB9C75aFDa38146e",
    "CALCULATOR_ADDRESS": "0x4307fbDCD9Ec7AEA5a1c2958deCaa6f316952bAb",
    "CALC_PRICELENS_ADDRESS": "0xcDc77D7799E3BC1B5A1D55d6D973BfD337cF5A16",
    "GLP_MANAGER_ADDRESS": "",
    "GM_BTC_PRICE_ADAPTER_ADDRESS": "",
    "GM_ETH_PRICE_ADAPTER_ADDRESS": "",
    "INTENT_ADDRESS": "",
    "ORDERBOOK_ORACLE_ADDRESS": "",
    "ADAPTIVE_FEE_CALCULATOR_ADDRESS": "",
  },
}

# ------ ABI Path ------
ERC20_ABI_PATH = "abis/ERC20.json"
CROSS_MARGIN_HANDLER_ABI_PATH = "abis/CrossMarginHandler.json"
LIMIT_TRADE_HANDLER_ABI_PATH = "abis/LimitTradeHandler.json"
VAULT_STORAGE_ABI_PATH = "abis/VaultStorage.json"
GLP_MANAGER_ABI_PATH = "abis/GlpManager.json"
PERP_STORAGE_ABI_PATH = "abis/PerpStorage.json"
CONFIG_STORAGE_ABI_PATH = "abis/ConfigStorage.json"
CIX_PRICE_ADAPTER_ABI_PATH = "abis/CIXPriceAdapter.json"
GM_PRICE_ADAPTER_ABI_PATH = "abis/GmPriceAdapter.json"
TRADE_HELPER_ABI_PATH = "abis/TradeHelper.json"
ONCHAIN_PRICELENS_ABI_PATH = "abis/OnchainPricelens.json"
CALC_PRICELENS_ABI_PATH = "abis/CalcPricelens.json"
CALCULATOR_ABI_PATH = "abis/Calculator.json"
ORDERBOOK_ORACLE_ABI = "abis/OrderbookOracle.json"
ADAPTIVE_FEE_CALCULATOR_ABI = "abis/AdaptiveFeeCalculator.json"
